/*
 *
 * Hands-On code of the book Introduction to Reliable Distributed Programming
 * by Christian Cachin, Rachid Guerraoui and Luis Rodrigues
 * Copyright (C) 2005-2011 Luis Rodrigues
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * Contact
 * 	Address:
 *		Rua Alves Redol 9, Office 605
 *		1000-029 Lisboa
 *		PORTUGAL
 * 	Email:
 * 		ler@ist.utl.pt
 * 	Web:
 *		http://homepages.gsd.inesc-id.pt/~ler/
 * 
 */

package irdp.protocols.tutorialDA.consensusUtils;

/**
 * Encapsulates a string for consensus.
 * 
 * @author alexp
 */
public class StringProposal extends Proposal {
  private static final long serialVersionUID = -2249937284480902746L;

  /**
   * The encapsulated string.
   */
  public String msg;

  public StringProposal(String s) {
    msg = s;
  }

  /**
   * @see java.lang.Comparable#compareTo(java.lang.Object)
   */
  public int compareTo(Proposal o) {
    if (!(o instanceof StringProposal))
      throw new ClassCastException("Required StringProposal");
    return msg.compareTo(((StringProposal) o).msg);
  }

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj) {
    return (obj instanceof StringProposal)
        && msg.equals(((StringProposal) obj).msg);
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode() {
    return msg.hashCode();
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString() {
    return "[StringProposal:\"" + msg.toString() + "\"]";
  }
}
